Event Type - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Event Type

Event types are what indicate what kind of thing an event is about, such as a birth, death, or marriage. They inherit from `betty.ancestry.event_type.event_types.EventType`.

## Built-in event types

`adoption` (`betty.ancestry.event_type.event_types.Adoption`)

  A person’s adoption.

`baptism` (`betty.ancestry.event_type.event_types.Baptism`)

  A person’s baptism.

`bar-mitzvah` (`betty.ancestry.event_type.event_types.BarMitzvah`)

  A person’s bar mitzvah.

`bat-mitzvah` (`betty.ancestry.event_type.event_types.BatMitzvah`)

  A person’s bat mitzvah.

`birth` (`betty.ancestry.event_type.event_types.Birth`)

  A person’s birth. This event type often receives special treatment and is considered the authoritative type to determine when somebody’s life started.

`burial` (`betty.ancestry.event_type.event_types.Burial`)

  A person’s burial.

`conference` (`betty.ancestry.event_type.event_types.Conference`)

  A conference.

`confirmation` (`betty.ancestry.event_type.event_types.Confirmation`)

  A christian confirmation.

`correspondence` (`betty.ancestry.event_type.event_types.Correspondence`)

  Correspondence between people, such as letters or emails.

`cremation` (`betty.ancestry.event_type.event_types.Cremation`)

  A person’s cremation.

`death` (`betty.ancestry.event_type.event_types.Death`)

  A person’s death. This event type often receives special treatment and is considered the authoritative type to determine when somebody’s life ended.

`divorce` (`betty.ancestry.event_type.event_types.Divorce`)

  A person’s divorce from another.

`divorce-announcement` (`betty.ancestry.event_type.event_types.DivorceAnnouncement`)

  The public announcement of a person’s divorce from another.

`emigration` (`betty.ancestry.event_type.event_types.Emigration`)

  A person’s emigration from a place.

`engagement` (`betty.ancestry.event_type.event_types.Engagement`)

  A person’s engagement to another.

`funeral` (`betty.ancestry.event_type.event_types.Funeral`)

  A person’s funeral.

`immigration` (`betty.ancestry.event_type.event_types.Immigration`)

  A person’s immigration to a place.

`marriage` (`betty.ancestry.event_type.event_types.Marriage`)

  A person’s marriage to another.

`marriage-announcement` (`betty.ancestry.event_type.event_types.MarriageAnnouncement`)

  The public announcement of a person’s marriage to another, such as marriage banns.

`missing` (`betty.ancestry.event_type.event_types.Missing`)

  When someone has become a missing person.

`occupation` (`betty.ancestry.event_type.event_types.Occupation`)

  How a person spends their time in society, such as through employment or education.

`residence` (`betty.ancestry.event_type.event_types.Residence`)

  A person stayed or lived in a place for some time.

`retirement` (`betty.ancestry.event_type.event_types.Retirement`)

  A person’s retirement from their occupations.

`unknown` (`betty.ancestry.event_type.event_types.Unknown`)

  The event’s type is not otherwise known.

`will` (`betty.ancestry.event_type.event_types.Will`)

  Any event associated with the reading and excution of someone’s will and testament.

## Built-in meta event types

The aforementioned event types can inherit from these meta types. For example, births and baptisms are both start-of-life events.

`betty.ancestry.event_type.event_types.StartOfLifeEventType`

  Any event taking place because of and close to someone’s birth, such as a baptism, or an actual birth.

`betty.ancestry.event_type.event_types.DuringLifeEventType`

  Any event taking place while the subject was still alive, e.g. between their birth and death.

`betty.ancestry.event_type.event_types.EndOfLifeEventType`

  Any event taking place because of and close to someone’s death, such as a funeral, or an actual death.

`betty.ancestry.event_type.event_types.PostDeathEventType`

  Any event taking place after someone’s death, such as a funeral or will reading.

`betty.ancestry.event_type.event_types.FinalDispositionEventType`

  Any final disposition, such as a burial or cremation.

## See also

- Event type plugins